==> gromacs_4.0.7.orig.tar.gz: gromacs-4.0.7/src/kernel/tpbcmp.h <==
/*
 * $Id$
 * 
 *                This source code is part of
 * 
 *                 G   R   O   M   A   C   S
 * 
 *          GROningen MAchine for Chemical Simulations
 * 
 *                        VERSION 3.2.0
 * Written by David van der Spoel, Erik Lindahl, Berk Hess, and others.
 * Copyright (c) 1991-2000, University of Groningen, The Netherlands.
 * Copyright (c) 2001-2004, The GROMACS development team,
 * check out http://www.gromacs.org for more information.

 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * If you want to redistribute modifications, please consider that
 * scientific software is very special. Version control is crucial -
 * bugs must be traceable. We will be happy to consider code for
 * inclusion in the official distribution, but derived work must not
 * be called official GROMACS. Details are found in the README & COPYING
 * files - if they are missing, get the official version at www.gromacs.org.
 * 
 * To help us fund GROMACS development, we humbly ask that you cite
 * the papers on the package - you can find them in the top README file.
 * 
 * For more info, check our website at http://www.gromacs.org
 * 
 * And Hey:
 * Gallium Rubidium Oxygen Manganese Argon Carbon Silicon
 */

#ifndef _tpbcmp_h
#define _tpbcmp_h

extern void comp_tpx(char *fn1,char *fn2,real ftol);
/* Compare two binary topology files */

extern void comp_trx(char *fn1,char *fn2,real ftol);
/* Compare two binary trajectory files */

extern void comp_enx(char *fn1,char *fn2,real ftol,char *lastener);
/* Compare two binary energy files */

#endif

==> gromacs_4.5.5.orig.tar.gz: gromacs-4.5.5/src/kernel/tpbcmp.h <==
/*
 * 
 *                This source code is part of
 * 
 *                 G   R   O   M   A   C   S
 * 
 *          GROningen MAchine for Chemical Simulations
 * 
 *                        VERSION 3.2.0
 * Written by David van der Spoel, Erik Lindahl, Berk Hess, and others.
 * Copyright (c) 1991-2000, University of Groningen, The Netherlands.
 * Copyright (c) 2001-2004, The GROMACS development team,
 * check out http://www.gromacs.org for more information.

 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * If you want to redistribute modifications, please consider that
 * scientific software is very special. Version control is crucial -
 * bugs must be traceable. We will be happy to consider code for
 * inclusion in the official distribution, but derived work must not
 * be called official GROMACS. Details are found in the README & COPYING
 * files - if they are missing, get the official version at www.gromacs.org.
 * 
 * To help us fund GROMACS development, we humbly ask that you cite
 * the papers on the package - you can find them in the top README file.
 * 
 * For more info, check our website at http://www.gromacs.org
 * 
 * And Hey:
 * Gallium Rubidium Oxygen Manganese Argon Carbon Silicon
 */

#ifndef _tpbcmp_h
#define _tpbcmp_h

void
comp_tpx(const char *fn1,const char *fn2,gmx_bool bRMSD,real ftol,real abstol);
/* Compare two binary topology files */

void
comp_trx(const output_env_t oenv,const char *fn1,const char *fn2,
	 gmx_bool bRMSD,real ftol,real abstol);
/* Compare two binary trajectory files */

void 
comp_enx(const char *fn1,const char *fn2,real ftol,real abstol,
                     const char *lastener);
/* Compare two binary energy files */

#endif
